AIMHII
=======================

This package provides software for identifying the genome insertion points random mutants generated by insertional mutagenesis, which have been sequenced as a pool.

The package will install two executables: aimhii and extract_chimeras.

aimhii will run a full analysis starting from sequence data (a FASTQ file), genome sequence, and insert sequence.  extract_chimeras just runs the last step of this analysis, assuming you already have a BAM file and a concatenated genome-insert sequence.

For details see the project website https://github.com/granek/aimhii/



Changes in v0.5.5: Added filter_bam.filter_chimeric_reads to pipeline extract only putative junction reads from BWA output. Shifted to hosting on github.

Changes in v0.5.4: Added --plot option to aimhii and shifted a few remaining "prints" to logging

Changes in v0.5.3: Shifted debugging prints to logging and added scripts for generating synthetic sequences

Changes in v0.5.2: Lowered pysam version requirement to allow installation using apt-get in Debian v8.

Changes in v0.5.1: Fixed problem with missing DESCRIPTION.rst.
